@@ -8,8 +8,8 @@ class Command(BaseCommand):
     help = "A wrapper for Avocado subcommands"
 
     commands = {
-        'sync': 'sync',
-        'orphaned': 'orphaned',
+        'init': 'init',
+        'check': 'check',
         'data': 'data',
         'cache': 'cache',
         'legacy': 'legacy',
